Async Utilities - kombu.syn — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# Async Utilities - kombu.syn

`kombu.syn.` `blocking`(fun, *args, **kwargs)

  Make sure function is called by blocking and waiting for the result, even if we’re currently in a monkey patched eventlet/gevent environment.

`kombu.syn.` `detect_environment`()

`kombu.syn.` `select_blocking_method`(type)

  Select blocking method, where type is one of default gevent or eventlet.

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »